﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Controls;
using testPagination;
using Infragistics.Windows;

namespace testPagination
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window, INotifyPropertyChanged
    {
        BindingList<Employee> dataSource = new BindingList<Employee>();

        public Window1()
        {
            InitializeComponent();
            dataSource = EmployeeData.GenerateEmployeeData();
            xamDataGrid1.DataSource = dataSource;

            xamDataGrid1.Loaded += new RoutedEventHandler(xamDataGrid1_Loaded);
        }


        /// <summary>
        /// Records in Page, Number of Pages calculation
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void xamDataGrid1_Loaded(object sender, RoutedEventArgs e)
        {
            XamDataGrid grid = (sender as XamDataGrid);
            AdjustGridWidth(grid);
        }

        /// <summary>
        /// Initiate Paging
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if ((sender as ComboBox).SelectedIndex == 0)
            {
                //Enable Paging
                PagingControl.Children.Clear();
                XamDataCarousel carousel = MainWindow.Resources["navigationDataCarouselControl"] as XamDataCarousel;
                carousel.ViewSettings.IsNavigatorVisible = false;
                PagingControl.Children.Add(carousel);
            }
            else
            {
                //Enable Paging
                PagingControl.Children.Clear();
                XamCarouselListBox carousel = MainWindow.Resources["navigationCarouselPanelControl"] as XamCarouselListBox;
                carousel.Width = 300;
                carousel.Height = 50;
                carousel.ViewSettings.IsNavigatorVisible = false;
                PagingControl.Children.Add(carousel);

            }
        }
        
        
        #region Paging Navigation

        private void XamDataCarousel_RecordActivated(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatedEventArgs e)
        {
            DataRecord dr = e.Record as DataRecord;
            //If Paging forwards
            if (this.CurrentPage < int.Parse(dr.Cells[0].Value.ToString()))
            {
                this.CurrentPage = int.Parse(dr.Cells[0].Value.ToString());

                //Handle the last page if is not full with records
                if (this.CurrentPage == this.NumberOfPages)
                {
                    xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[xamDataGrid1.Records.Count - 1]);
                    return;
                }
                xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[CurrentPage * this.RecordsInPage + this.RecordsInPage - 1]);
            }
            //Else Paging backwards
            else
            {
                this.CurrentPage = int.Parse(dr.Cells[0].Value.ToString());
                xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[CurrentPage * this.RecordsInPage]);
            }
        }

        private void XamCarouselListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            int selectedIndex = int.Parse(e.AddedItems[0].ToString());
            //If Paging forwards
            if (this.CurrentPage < selectedIndex)
            {
                this.CurrentPage = selectedIndex;

                //Handle the last page if is not full with records
                if (this.CurrentPage == this.NumberOfPages)
                {
                    xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[xamDataGrid1.Records.Count - 1]);
                    return;
                }
                xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[CurrentPage * this.RecordsInPage + this.RecordsInPage - 1]);
            }
            //Else Paging backwards
            else
            {
                this.CurrentPage = selectedIndex;
                xamDataGrid1.BringRecordIntoView(xamDataGrid1.Records[CurrentPage * this.RecordsInPage]);
            }
        }

        #endregion

        /// <summary>
        /// Pagination Dependency Properties
        /// </summary>
        #region Dependency Properties

        public int CurrentPage
        {
            get { return (int)GetValue(CurrentPageProperty); }
            set
            {
                if (value != this.CurrentPage)
                {
                    SetValue(CurrentPageProperty, value);
                    NotifyPropertyChanged("CurrentPage");
                }
            }
        }

        public static readonly DependencyProperty CurrentPageProperty =
            DependencyProperty.Register("CurrentPage", typeof(int), typeof(XamDataGrid), new UIPropertyMetadata(0));



        public int NumberOfPages
        {
            get { return (int)GetValue(NumberOfPagesProperty); }
            set
            {
                if (value != this.NumberOfPages)
                {
                    SetValue(NumberOfPagesProperty, value);
                    NotifyPropertyChanged("NumberOfPages");
                }
            }
        }

        public static readonly DependencyProperty NumberOfPagesProperty =
            DependencyProperty.Register("NumberOfPages", typeof(int), typeof(XamDataGrid), new UIPropertyMetadata(0));



        public int RecordsInPage
        {
            get { return (int)GetValue(RecordsInPageProperty); }
            set
            {
                if (value != this.RecordsInPage)
                {
                    SetValue(RecordsInPageProperty, value);
                    NotifyPropertyChanged("RecordsInPage");
                }
            }
        }

        public static readonly DependencyProperty RecordsInPageProperty =
            DependencyProperty.Register("RecordsInPage", typeof(int), typeof(XamDataGrid), new UIPropertyMetadata(5));

        #endregion

        /// <summary>
        /// INotifyPropertyChanged
        /// </summary>
        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        #endregion

        private void tbRPP_EditModeEnded(object sender, Infragistics.Windows.Editors.Events.EditModeEndedEventArgs e)
        {
            int tempRecordsInPage;
            if (int.TryParse(tbRPP.Value.ToString(), out tempRecordsInPage))
            {
                if (tempRecordsInPage == 0)
                {
                    this.RecordsInPage = 1;
                }
                else
                {
                    this.RecordsInPage = tempRecordsInPage;
                }
                AdjustGridWidth(xamDataGrid1);
            }
        }

        private void AdjustGridWidth(XamDataGrid grid)
        {
            //Calculate exact items per page
            DataRecordPresenter dr = DataRecordPresenter.FromRecord(grid.GetRecordsInView(false).First()) as DataRecordPresenter;
            double height = dr.ActualHeight;
            double labelHeight = xamDataGrid1.FieldLayouts[0].Fields[0].LabelHeightResolved;
            grid.MaxHeight = this.RecordsInPage * height + labelHeight + 1;
            int allRecords = grid.Records.Count;

            //Calculate Records per page
            this.RecordsInPage = grid.GetRecordsInView(false).Length - 1;

            //Calculate Numer of pages
            this.NumberOfPages = allRecords / this.RecordsInPage;
        }

        

    }
}
